@@ -33,6 +33,7 @@ OC.L10N.register(
     "Automatic trash deletion" : "Desaniciu automáticu de la papelera",
     "Autoresponder" : "Rempuesta automática",
     "Please connect to a sieve server first." : "Conéctate a un sirvidor sieve primero.",
+    "Filters" : "Filtros",
     "Mail server" : "Sirvidor de corréu electrónicu",
     "Go back" : "Dir p'atrás",
     "Change name" : "Camudar el nome",
@@ -237,6 +238,11 @@ OC.L10N.register(
     "Untitled event" : "Eventu ensin títulu",
     "Airplane" : "Avión",
     "Train" : "Tren",
+    "Flag" : "Bandera",
+    "Operator" : "Operador",
+    "Filter name" : "Nome de la peñera",
+    "Actions" : "Aiciones",
+    "Priority" : "Prioridá",
     "Anti Spam Service" : "Serviciu de antispam",
     "Gmail integration" : "Integración con Gmail",
     "Error saving config" : "Hebo un error al guardar la configuración",
