@@ -95,9 +95,10 @@ OC.L10N.register(
     "Autoresponder" : "Automatická odpověď",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatická odpověď na příchozí zprávy. Pokud vám někdo pošle vícero zpráv, tato automatická odpověď bude odeslána nanejvýš co 4 dny.",
     "Please connect to a sieve server first." : "Nejprve se prosím připojte k sieve serveru.",
-    "Sieve filter rules" : "Pravidla sieve filtru",
+    "Filters" : "Filtry",
+    "Sieve script editor" : "Editor sieve skriptů",
     "Mail server" : "E-mailový server",
-    "Sieve filter server" : "Filtrovací server sieve",
+    "Sieve server" : "Sieve server",
     "Mailbox search" : "Hledání ve schránce",
     "Update alias" : "Aktualizovat alternativní název",
     "Rename alias" : "Přejmenovat alternativní název",
@@ -441,6 +442,7 @@ OC.L10N.register(
     "Message could not be sent" : "Zprávu se nepodařilo odeslat",
     "Message deleted" : "Zpráva smazána",
     "Phishing email" : "Phisingový e-mail",
+    "This email might be a phishing attempt" : "Tento e-mail by mohl být pokusem o phishing",
     "Hide suspicious links" : "Skrýt podezřelé odkazy",
     "Show suspicious links" : "Zobrazit podezřelé odkazy",
     "link text" : "text odkazu",
@@ -469,12 +471,13 @@ OC.L10N.register(
     "Select tags" : "Výběr štítků",
     "Marked as" : "Označeno jako",
     "Has attachments" : "Má přílohy",
+    "Mentions me" : "Zmiňuje mne",
     "Has attachment" : "Má přílohu",
     "Last 7 days" : "Uplynulých 7 dnů",
     "From me" : "Ode mne",
     "Clear" : "Vyčistit",
     "Enable mail body search" : "Zapnout hledání v těle zprávy",
-    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it." : "Sieve je mocný jazyk pro psaní filtrovacích pravidel pro e-mailovou schránku. Pokud je vámi využívaná e-mailová služba podporuje, je možné zpravovat sieve skripty v aplikaci E-mail.",
+    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve je mocný jazyk pro psaní filtrovacích pravidel pro e-mailovou schránku. Pokud je vámi využívaná e-mailová služba podporuje, je možné zpravovat sieve skripty v aplikaci E-mail. Sieve je také vyžadováno použít v automatických odpovědích a filtrech.",
     "Enable sieve filter" : "Zapnout sieve filtr",
     "Sieve host" : "Stroj se sieve",
     "Sieve security" : "Zabezpečení sieve",
@@ -553,6 +556,41 @@ OC.L10N.register(
     "Train" : "Vlak",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} z {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak z {depStation} do {arrStation}",
+    "Delete action" : "Akce smazání",
+    "Flag" : "Vlajka",
+    "The stop action ends all processing" : "Akce stop ukončí veškeré zpracovávání",
+    "Delete mail filter {filterName}?" : "Smazat filtr e-mailů {filterName}?",
+    "Are you sure to delete the mail filter?" : "Opravdu chcete tento filtr smazat?",
+    "Delete filter" : "Smazat filtr",
+    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Zkroťte chaos ve svých e-mailech. Filtry vám pomohou vypíchnout co je důlečité a eliminovat nepořádek.",
+    "Filter is active" : "Filtr je aktivní",
+    "Filter is not active" : "Filtr není aktivní",
+    "New filter" : "Nový filtr",
+    "Filter saved" : "Filtr uložen",
+    "Could not save filter" : "Filtr se nepodařilo uložit",
+    "Filter deleted" : "Filtr smazán",
+    "Could not delete filter" : "Filtr se nepodařilo smazat",
+    "Operator" : "Operátor",
+    "If all tests pass, then the actions will be executed" : "Pokud veškeré testy projdou, pak budou akce vykonány",
+    "If one test pass, then the actions will be executed" : "Pokud jeden test projde, pak budou akce vykonány",
+    "Delete test" : "Smazat test",
+    "Update mail filter" : "Zaktualizovat filtr e-mailů",
+    "Filter name" : "Název filtru",
+    "Tests" : "Testy",
+    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Testy jsou uplatňovány na příchozí e-maily na vašem e-mailovém serveru, cílí na kolonky jako např. předmět (tj. řádek předmět e-mailu), od (odesilate) a pro (příjemce). Pro definování podmínek pro tyto kolonky je monžé použít následující operátory:",
+    "An exact match. The field must be identical to the provided value." : "Přesná shoda. Je třeba, aby obsah kolonky přesně stejný, jako zadaná hodnota.",
+    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Shoda v části řetězce. Kolonka odpovídá, pokud je v ní zadaná hodnota obsažena. Například „hlášení“ by se shodoval s „hláš“.",
+    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Shoda s řetězcem pomocí zástupných znaků. Symbol „*“ (hvězdička) představuje libovolný počet znaků (včetně žádného), zatímco „?“ (otazník) odpovídá přesně jednomu znaku. Například, „hlášení*“ by se shodovalo s „hlášení o podníkání 2024“.",
+    "New test" : "Nový test",
+    "Actions" : "Akce",
+    "Actions are triggered when the specified tests are true. The following actions are available:" : "Akce jsou spouštěny pokud jsou splněny zadané testy. K dispozici jsou následující akce:",
+    "Moves the message into a specified folder." : "Přesune zprávu do zadané složky.",
+    "Adds a flag to the message." : "Přidá zprávě příznak.",
+    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Zastaví vykonávání filtrovacího skriptu. Po této akci nebudou zpracovávány žádné další filtry.",
+    "New action" : "Nová akce",
+    "Priority" : "Priorita",
+    "Enable filter" : "Zapnout filtr",
+    "Save filter" : "Uložit filtr",
     "Mail app" : "E-mailová aplikace",
     "The mail app allows users to read mails on their IMAP accounts." : "E-mailová aplikace která uživatelům umožňuje číst e-maily ve svých IMAP účtech.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Zde naleznete nastavení pro celou instanci. Nastavení pro jednotlivé uživatele se nachází v aplikaci samotné (levý dolní roh).",
@@ -706,6 +744,9 @@ OC.L10N.register(
     "The link leads to %s" : "Odkaz vede na %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
     "Continue to %s" : "Pokračovat na %s",
-    "Account creation" : "Vytváření účtů"
+    "Sieve filter rules" : "Pravidla sieve filtru",
+    "Sieve filter server" : "Filtrovací server sieve",
+    "Account creation" : "Vytváření účtů",
+    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it." : "Sieve je mocný jazyk pro psaní filtrovacích pravidel pro e-mailovou schránku. Pokud je vámi využívaná e-mailová služba podporuje, je možné zpravovat sieve skripty v aplikaci E-mail."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
