@@ -58,6 +58,7 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Προτιμώμενη λειτουργία σύνταξης για νέα μηνύματα και απαντήσεις.",
     "Default folders" : "Προεπιλεγμένοι φάκελοι",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Αυτοματοποιημένη απάντηση σε εισερχόμενα μηνύματα. Εάν κάποιος σας στείλει πολλά μηνύματα, αυτή η αυτοματοποιημένη απάντηση θα αποστέλλεται το πολύ μία φορά κάθε 4 ημέρες.",
+    "Filters" : "Φίλτρα",
     "Mail server" : "Διακομιστής αλληλογραφίας",
     "Update alias" : "Ενημέρωση ψευδώνυμου",
     "Show update alias form" : "Εμφάνιση φόρμας ενημέρωσης ψευδώνυμου",
@@ -318,6 +319,10 @@ OC.L10N.register(
     "Train" : "Τρένο",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} από {depStation} προς {arrStation}",
     "Train from {depStation} to {arrStation}" : "Τρένο από {depStation} προς {arrStation}",
+    "Delete filter" : "Διαγραφή φίλτρου",
+    "Operator" : "Διαχειριστής",
+    "Actions" : "Ενέργειες",
+    "Priority" : "Προτεραιότητα",
     "Mail app" : "Εφαρμογή αλληλογραφίας",
     "The mail app allows users to read mails on their IMAP accounts." : "Η εφαρμογή ταχυδρομείου επιτρέπει στους χρήστες να διαβάζουν μηνύματα από τους λογαριασμούς τους IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Εδώ μπορείτε να βρείτε ρυθμίσεις για το περιστατικό. Οι συγκεκριμένες ρυθμίσεις χρήστη βρίσκονται στην ίδια την εφαρμογή (κάτω αριστερή γωνία).",
