@@ -93,6 +93,9 @@ OC.L10N.register(
     "Select tags" : "Selecciona las etiquetas",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
+    "Operator" : "Operador",
+    "Actions" : "Acciones",
+    "Priority" : "Prioridad",
     "Reset" : "Restaurar",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
