@@ -50,9 +50,7 @@ OC.L10N.register(
     "Writing mode" : "Modo de escritura",
     "Preferred writing mode for new messages and replies." : "Modo preferido de escritura para nuevos mensajes y respuestas.",
     "Default folders" : "Carpetas predeterminadas",
-    "Sieve filter rules" : "Reglas del filtro de Sieve",
     "Mail server" : "Servidor de correo",
-    "Sieve filter server" : "Servidor de filtros Sieve",
     "Update alias" : "Actualizar alias",
     "Show update alias form" : "Mostrar formulario de actualización de alias",
     "Delete alias" : "Borrar alias",
@@ -161,6 +159,8 @@ OC.L10N.register(
     "Clear" : "Limpiar",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
+    "Actions" : "Acciones",
+    "Priority" : "Prioridad",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
@@ -192,6 +192,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Sieve filter rules" : "Reglas del filtro de Sieve",
+    "Sieve filter server" : "Servidor de filtros Sieve"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
