@@ -26,6 +26,7 @@ OC.L10N.register(
     "Password required" : "Se requiere contraseña",
     "Aliases" : "Aliases",
     "Signature" : "Firma",
+    "Filters" : "Filtros",
     "Go back" : "Regresar",
     "Change name" : "Cambiar nombre",
     "Email address" : "Dirección de correo electrónico",
@@ -119,6 +120,9 @@ OC.L10N.register(
     "Not found" : "No encontrado",
     "(organizer)" : "(organizador)",
     "Untitled event" : "Evento sin título",
+    "Operator" : "Operador",
+    "Actions" : "Acciones",
+    "Priority" : "Prioridad",
     "Reset" : "Reiniciar",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
