@@ -29,8 +29,10 @@ OC.L10N.register(
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
+    "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Register" : "Registrar",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
     "Older message" : "Mensaje más antiguo",
@@ -62,13 +64,14 @@ OC.L10N.register(
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
+    "Remove" : "Eliminar",
+    "email" : "correo electrónico",
     "Other" : "Otro",
-    "Reply" : "Responder",
+    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
     "Unnamed" : "Sin nombre",
-    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
@@ -76,26 +79,26 @@ OC.L10N.register(
     "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
+    "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
+    "Reply" : "Responder",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
     "Close" : "Cerrar",
+    "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
-    "Date" : "Fecha",
-    "Disabled" : "Deshabilitado",
-    "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
-    "Remove" : "Eliminar",
+    "Actions" : "Acciones",
+    "Priority" : "Prioridad",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
-    "General" : "General",
     "User" : "Ususario",
     "Host" : "Servidor",
     "Port" : "Puerto",
