@@ -71,6 +71,7 @@ OC.L10N.register(
     "Add alias" : "Pridėti alternatyvų vardą",
     "Cancel" : "Atsisakyti",
     "Mail settings" : "Pašto nustatymai",
+    "Accounts" : "Paskyros",
     "Add mail account" : "Pridėti pašto paskyrą",
     "General" : "Bendra",
     "Layout" : "Išdėstymas",
@@ -81,8 +82,12 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
     "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
     "Register" : "Registruotis",
+    "Privacy and security" : "Privatumas ir saugumas",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
     "Trusted senders" : "Patikimi siuntėjai",
+    "Internal addresses" : "Vidiniai adresai",
+    "S/MIME" : "S/MIME",
+    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
     "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?",
     "Keyboard shortcuts" : "Spartieji klavišai",
     "Compose new message" : "Rašyti naują laišką",
@@ -96,6 +101,9 @@ OC.L10N.register(
     "Send" : "Siųsti",
     "Refresh" : "Įkelti iš naujo",
     "Could not update preference" : "Nepavyko atnaujinti nuostatos",
+    "Certificate updated" : "Liudijimas atnaujintas",
+    "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} – Galioja iki {expiryDate}",
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
     "To" : "Kam",
@@ -136,6 +144,8 @@ OC.L10N.register(
     "Choose" : "Pasirinkite",
     "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
     "Confirm" : "Patvirtinti",
+    "Tag: {name} deleted" : "Žymė: {name} ištrinta",
+    "An error occurred, unable to delete the tag." : "Įvyko klaida, nepavyko ištrinti žymės.",
     "Plain text" : "Grynasis tekstas",
     "Rich text" : "Raiškusis tekstas",
     "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
@@ -149,6 +159,9 @@ OC.L10N.register(
     "Unselect" : "Nuimti žymėjimą",
     "Select" : "Pasirinkti",
     "Edit tags" : "Redaguoti žymes",
+    "Move thread" : "Perkelti giją",
+    "Archive thread" : "Archyvuoti giją",
+    "Delete thread" : "Ištrinti giją",
     "More actions" : "Daugiau veiksmų",
     "Back" : "Atgal",
     "Edit as new message" : "Taisyti kaip naują laišką",
@@ -177,8 +190,13 @@ OC.L10N.register(
     "More options" : "Daugiau parinkčių",
     "This event is in the past." : "Šis įvykis yra praeityje.",
     "This event was updated" : "Šis įvykis buvo atnaujintas",
+    "{attendeeName} accepted your invitation" : "{attendeeName} priėmė jūsų pakvietimą",
+    "{attendeeName} declined your invitation" : "{attendeeName} atmetė jūsų pakvietimą",
     "Remove" : "Šalinti",
     "email" : "elektroninis paštas",
+    "Add internal address" : "Pridėti vidinį adresą",
+    "Could not remove internal address {sender}" : "Nepavyko pašalinti vidinio adreso {sender}",
+    "Could not add internal address {address}" : "Nepavyko pridėti vidinį adresą {address}",
     "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
     "Loading messages …" : "Įkeliami laiškai…",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
@@ -196,9 +214,12 @@ OC.L10N.register(
     "Save to Files" : "Įrašyti į Failus",
     "Unnamed" : "Be pavadinimo",
     "Embedded message" : "Įterptas laiškas",
+    "Attachment could not be saved" : "Nepavyko įrašyti priedo",
+    "calendar imported" : "kalendorius importuotas",
     "View fewer attachments" : "Rodyti mažiau priedų",
     "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
     "Save all to Files" : "Įrašyti visus į Failus",
+    "Error while saving attachments" : "Klaida įrašant priedus",
     "_View {count} more attachment_::_View {count} more attachments_" : ["Rodyti dar {count} priedą","Rodyti dar {count} priedus","Rodyti dar {count} priedų","Rodyti dar {count} priedą"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
     "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
@@ -211,6 +232,7 @@ OC.L10N.register(
     "Quota" : "Leidžiamas duomenų kiekis",
     "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
     "Add mailbox" : "Pridėti pašto dėžutę",
+    "Mailbox name" : "Pašto dėžutės pavadinimas",
     "Saving" : "Įrašoma",
     "Move up" : "Pakelti",
     "Move down" : "Nuleisti",
@@ -226,10 +248,14 @@ OC.L10N.register(
     "Mark all as read" : "Žymėti visus kaip skaitytus",
     "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
     "Rename" : "Pervadinti",
+    "Move mailbox" : "Perkelti pašto dėžutę",
     "Clear cache" : "Išvalyti podėlį",
     "Subscribed" : "Prenumeruotas",
     "Sync in background" : "Sinchronizuoti fone",
+    "Clear mailbox" : "Išvalyti pašto dėžutę",
     "Delete mailbox" : "Ištrinti pašto dėžutę",
+    "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
+    "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
     "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
     "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
     "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
@@ -246,6 +272,7 @@ OC.L10N.register(
     "Message saved" : "Laiškas įrašytas",
     "Failed to save message" : "Nepavyko įrašyti laiško",
     "Failed to save draft" : "Nepavyko įrašyti juodraščio",
+    "attachment" : "priedas",
     "Message discarded" : "Laiškas atmestas",
     "Could not discard message" : "Nepavyko atmesti laiško",
     "Autoresponder off" : "Atsakiklis išjungtas",
@@ -253,13 +280,18 @@ OC.L10N.register(
     "Message" : "Žinutė",
     "Oh Snap!" : "O, ne!",
     "Pending or not sent messages will show up here" : "Čia bus rodomi laukiantys ar neišsiųsti laiškai",
+    "Mail server error" : "Pašto serverio klaida",
     "Message could not be sent" : "Nepavyko išsiųsti laiško",
     "Message deleted" : "Laiškas ištrintas",
+    "Hide suspicious links" : "Slėpti įtartinas nuorodas",
+    "Show suspicious links" : "Rodyti įtartinas nuorodas",
     "Contacts with this address" : "Adresatai turintys šį adresą",
     "New Contact" : "Naujas adresatas",
     "Copy to clipboard" : "Kopijuoti į iškarpinę",
     "Contact name …" : "Adresato vardas…",
     "Add" : "Pridėti",
+    "Copied email address to clipboard" : "El. pašto adresas nukopijuotas į iškarpinę",
+    "Could not copy email address to clipboard" : "Nepavyko nukopijuoti el. pašto adreso į iškarpinę",
     "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Close" : "Užverti",
     "Date" : "Data",
@@ -272,9 +304,12 @@ OC.L10N.register(
     "Save signature" : "Įrašyti parašą",
     "Delete tag" : "Ištrinti žymę",
     "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymės.",
+    "Add default tags" : "Pridėti numatytąsias žymes",
     "Add tag" : "Pridėti žymę",
     "Saving tag …" : "Įrašoma žymė…",
+    "Tag name is a hidden system tag" : "Žymės pavadinimas yra paslėpta sistemos žymė",
     "Tag already exists" : "Žymė jau yra",
+    "Tag name cannot be empty" : "Žymės pavadinimas negali būti tuščias",
     "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymės.",
     "Not found" : "Nerasta",
     "Unsubscribe" : "Atsisakyti prenumeratos",
@@ -284,6 +319,9 @@ OC.L10N.register(
     "Mark as read" : "Žymėti kaip skaitytą",
     "Delete message" : "Ištrinti laišką",
     "Message source" : "Pirminis laiško kodas",
+    "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
+    "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
+    "This message was encrypted by the sender before it was sent." : "Siuntėjas, prieš išsiųsdamas šį laišką, jį užšifravo.",
     "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
     "(organizer)" : "(organizatorius)",
@@ -296,16 +334,40 @@ OC.L10N.register(
     "Train" : "Traukinys",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
     "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
+    "Delete action" : "Ištrinti veiksmą",
+    "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
+    "Delete filter" : "Ištrinti filtrą",
+    "New filter" : "Naujas filtras",
+    "Filter saved" : "Filtras įrašytas",
+    "Could not save filter" : "Nepavyko įrašyti filtro",
+    "Filter deleted" : "Filtras ištrintas",
+    "Could not delete filter" : "Nepavyko ištrinti filtro",
+    "Actions" : "Veiksmai",
+    "New action" : "Naujas veiksmas",
+    "Priority" : "Pirmenybė",
+    "Enable filter" : "Įjungti filtrą",
+    "Save filter" : "Įrašyti filtrą",
     "Mail app" : "Pašto programėlė",
     "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Čia galite rasti egzemplioriaus masto nustatymus. Specifinius naudotojo nustatymus galite rasti pačioje programėlėje (apatiniame kairiajame kampe).",
     "Add new config" : "Pridėti naują konfigūraciją",
+    "Allow additional mail accounts" : "Leisti papildomas pašto paskyras",
+    "Gmail integration" : "„Gmail“ integracija",
+    "Microsoft integration" : "„Microsoft“ integracija",
     "Error saving config" : "Klaida įrašant konfigūraciją",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Pradinis laiškas bus pridėtas kaip priedas „message/rfc822“.",
     "Reset" : "Atstatyti",
     "Client ID" : "Kliento ID",
     "Client secret" : "Kliento paslaptis",
     "Unlink" : "Atsieti",
+    "Google integration configured" : "„Google“ integracija sukonfigūruota",
+    "Could not configure Google integration" : "Nepavyko sukonfigūruoti „Google“ integracijos",
+    "Google integration unlinked" : "„Google“ integracija atsieta",
+    "Could not unlink Google integration" : "Nepavyko atsieti „Google“ integracijos",
+    "Microsoft integration configured" : "„Microsoft“ integracija sukonfigūruota",
+    "Could not configure Microsoft integration" : "Nepavyko sukonfigūruoti „Microsoft“ integracijos",
+    "Microsoft integration unlinked" : "„Microsoft“ integracija atsieta",
+    "Could not unlink Microsoft integration" : "Nepavyko atsieti „Microsoft“ integracijos",
     "Email: {email}" : "El. paštas: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
@@ -318,6 +380,7 @@ OC.L10N.register(
     "Save Config" : "Įrašyti konfigūraciją",
     "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
     "S/MIME certificates" : "S/MIME liudijimai",
+    "Certificate name" : "Liudijimo pavadinimas",
     "E-mail address" : "El. pašto adresas",
     "Valid until" : "Galioja iki",
     "Delete certificate" : "Ištrinti liudijimą",
@@ -365,6 +428,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
-    "Continue to %s" : "Tęsti į %s"
+    "Continue to %s" : "Tęsti į %s",
+    "Account creation" : "Paskyros sukūrimas"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
