@@ -72,6 +72,7 @@ OC.L10N.register(
     "Automatic trash deletion" : "Автоматско бришење на корпата со отпадоци",
     "Days after which messages in Trash will automatically be deleted:" : "Денови по кои пораките во корпата автоматски ќе се избришат:",
     "Autoresponder" : "Автоматски одговор",
+    "Filters" : "Филтри",
     "Mail server" : "Сервер за е-пошта",
     "Update alias" : "Ажурирај алијас",
     "Delete alias" : "Избриши алијас",
@@ -359,6 +360,10 @@ OC.L10N.register(
     "Train" : "Воз",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
+    "Flag" : "Знаме",
+    "Actions" : "Акции",
+    "New action" : "Нова акција",
+    "Priority" : "Приоритет",
     "Mail app" : "Апликација Електронска пошта",
     "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде може да се пронајде поопшитно прилагодување. Специфични параметри за корисниците може да се пронајдат во самата апликација (доле-лево).",
