@@ -81,9 +81,8 @@ OC.L10N.register(
     "Autoresponder" : "Automatyczna wiadomość zwrotna",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatyczna odpowiedź na przychodzące wiadomości. Jeśli ktoś wyśle Tobie kilka wiadomości, ta automatyczna odpowiedź będzie wysyłana co najwyżej raz na 4 dni.",
     "Please connect to a sieve server first." : "Najpierw połącz się z serwerem Sieve.",
-    "Sieve filter rules" : "Zasady filtra Sieve",
+    "Filters" : "Filtry",
     "Mail server" : "Serwer poczty",
-    "Sieve filter server" : "Serwer filtra Sieve",
     "Update alias" : "Zaktualizuj alias",
     "Rename alias" : "Zmień nazwę aliasu",
     "Show update alias form" : "Pokaż formularz aktualizacji aliasu",
@@ -407,6 +406,11 @@ OC.L10N.register(
     "Train" : "Pociąg",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} z {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Pociąg z {depStation} do {arrStation}",
+    "Flag" : "Flaga",
+    "Operator" : "Operator",
+    "Actions" : "Akcje",
+    "New action" : "Nowa akcja",
+    "Priority" : "Priorytet",
     "Mail app" : "Aplikacja poczty",
     "The mail app allows users to read mails on their IMAP accounts." : "Aplikacja poczty pozwala użytkownikom czytać wiadomości e-mail na kontach IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tutaj możesz znaleźć ustawienia dotyczące całej instancji. Ustawienia użytkownika można znaleźć w samej aplikacji (lewy dolny róg).",
@@ -536,6 +540,8 @@ OC.L10N.register(
     "The link leads to %s" : "Link prowadzi do %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
     "Continue to %s" : "Kontynuuj do %s",
+    "Sieve filter rules" : "Zasady filtra Sieve",
+    "Sieve filter server" : "Serwer filtra Sieve",
     "Account creation" : "Tworzenie konta"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
