@@ -181,6 +181,10 @@ OC.L10N.register(
     "Airplane" : "Avião",
     "Reservation {id}" : "Reserva {id}",
     "Train" : "Comboio",
+    "Operator" : "Operador",
+    "Actions" : "Acções",
+    "New action" : "Nova ação",
+    "Priority" : "Prioridade",
     "Reset" : "Reiniciar",
     "Client ID" : "Id. do Cliente",
     "Client secret" : "Segredo do cliente\\\\",
