@@ -44,9 +44,7 @@ OC.L10N.register(
     "Writing mode" : "Modalidade de iscritura",
     "Preferred writing mode for new messages and replies." : "Modalidade de iscritura preferida pro is messàgios noos e de is respostas.",
     "Default folders" : "Cartellas predefinidas",
-    "Sieve filter rules" : "Règulas de filtru Sieve",
     "Mail server" : "Serbidore de posta",
-    "Sieve filter server" : "Serbidore de filtru Sieve",
     "Update alias" : "Agiorna identidade",
     "Show update alias form" : "Mustra s'agiornamentu de sa forma de su identidade",
     "Delete alias" : "Cantzella identidade",
@@ -59,6 +57,7 @@ OC.L10N.register(
     "Add mail account" : "Agiunghe contu de posta",
     "General" : "Generale",
     "Sorting" : "Assentende",
+    "Newest" : "Prus nou",
     "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
     "Register" : "Registra",
@@ -243,6 +242,7 @@ OC.L10N.register(
     "Signature …" : "Firma ...",
     "Save signature" : "Sarva firma",
     "Place signature above quoted text" : "Pone sa firma subra su testu tzitadu",
+    "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
     "Add tag" : "Agiunghe eticheta",
     "Saving tag …" : "Sarvende s'eticheta ...",
     "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
@@ -254,6 +254,7 @@ OC.L10N.register(
     "Mark as read" : "Marca comente lèghidu",
     "Delete message" : "Cantzella messàgiu",
     "Message source" : "Fonte de su messàgiu",
+    "Go to newest message" : "Bae a su messàgiu prus nou",
     "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
     "Could not remove trusted sender {sender}" : "No at fatu a nche bogare s'imbiante afidàbile {sender}",
     "(organizer)" : "(persona organizadora)",
@@ -266,6 +267,11 @@ OC.L10N.register(
     "Train" : "Trenu",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} dae {depStation} a {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trenu dae {depStation} a {arrStation}",
+    "New filter" : "Filtru nou",
+    "New test" : "Proa noa",
+    "Actions" : "Atziones",
+    "New action" : "Atzione noa",
+    "Priority" : "Prioridade",
     "Mail app" : "Aplicatzione de posta",
     "The mail app allows users to read mails on their IMAP accounts." : "S'aplicatzione de posta permitit a is utentes de lèghere is messàgios de is contos IMAP issoro.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Inoghe podes agatare sa cunfiguratzione pro totu s'istàntzia. Is cunfiguratziones ispetzìficas de s'utente sunt in s'aplicatzione etotu (in bàsciu a manca).",
@@ -342,6 +348,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Incarca inoghe chi no ses torradu a deretare in manera automàtica intro de pagu segundos.",
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
-    "Continue to %s" : "Sighi in %s"
+    "Continue to %s" : "Sighi in %s",
+    "Sieve filter rules" : "Règulas de filtru Sieve",
+    "Sieve filter server" : "Serbidore de filtru Sieve"
 },
 "nplurals=2; plural=(n != 1);");
