@@ -72,9 +72,8 @@ OC.L10N.register(
     "Writing mode" : "Način pisanja",
     "Preferred writing mode for new messages and replies." : "Prednostni način pisanja sporočil za nova sporočila in odgovore.",
     "Default folders" : "Privzete mape",
-    "Sieve filter rules" : "Pravila filtra Sieve",
+    "Filters" : "Filtri",
     "Mail server" : "Poštni strežnik",
-    "Sieve filter server" : "Strežnik filtra Sieve",
     "Mailbox search" : "Iskanje po poštnem predalu",
     "Update alias" : "Posodobi vzdevek",
     "Rename alias" : "Preimenuj vzdevek",
@@ -414,6 +413,11 @@ OC.L10N.register(
     "Train" : "Vlak",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} v {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} v {arrStation}",
+    "Flag" : "Zastava",
+    "Delete filter" : "Izbriši filter",
+    "Operator" : "Operator",
+    "Actions" : "Dejanja",
+    "Priority" : "Prednost",
     "Mail app" : "Program Pošta",
     "The mail app allows users to read mails on their IMAP accounts." : "Program Mail omogoča uporabnikom branje sporočil z računov IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Na tem mestu so zbrane nastavitve celotnega okolja. Uporabniške nastavitve so v posameznem programu (spodnji levi kot).",
@@ -516,6 +520,8 @@ OC.L10N.register(
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
     "Continue to %s" : "Nadaljuj na %s",
+    "Sieve filter rules" : "Pravila filtra Sieve",
+    "Sieve filter server" : "Strežnik filtra Sieve",
     "Account creation" : "Ustvarjanje računa"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
