@@ -50,6 +50,7 @@ OC.L10N.register(
     "Writing mode" : "Skrivläge",
     "Preferred writing mode for new messages and replies." : "Föredraget skrivläge för nya meddelanden och svar.",
     "Default folders" : "Standardmappar",
+    "Filters" : "Filter",
     "Mail server" : "E-postserver",
     "Update alias" : "Uppdatera alias",
     "Delete alias" : "Radera alias",
@@ -64,6 +65,8 @@ OC.L10N.register(
     "General" : "Allmänt",
     "Layout" : "Layout",
     "Sorting" : "Sortering",
+    "Newest" : "Nyast",
+    "Oldest" : "Äldst",
     "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
     "Register as application for mail links" : "Registrera som app för e-postlänkar",
     "Register" : "Registrera",
@@ -286,6 +289,12 @@ OC.L10N.register(
     "Train" : "Tåg",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} från {depStation} till {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
+    "Delete filter" : "Ta bort filter",
+    "Operator" : "Operatör",
+    "Filter name" : "Filternamn",
+    "Actions" : "Funktioner",
+    "New action" : "Ny åtgärd",
+    "Priority" : "Prioritet",
     "Mail app" : "Mail-app",
     "The mail app allows users to read mails on their IMAP accounts." : "Mail-appen tillåter användare att läsa e-post på sina IMAP-konton.",
     "Reset" : "Återställ",
@@ -326,6 +335,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
     "Nextcloud Mail" : "Nextcloud E-post",
+    "Discard changes" : "Släng ändringar",
     "Attachments were not copied. Please add them manually." : "Bifogade filer kopierades inte, lägg till dem manuellt.",
     "Message sent" : "Meddelande skickat",
     "Could not load {tag}{name}{endtag}" : "Kunde inte läsa in {tag}{name}{endtag}",
