@@ -84,9 +84,8 @@ OC.L10N.register(
     "Autoresponder" : "Автовідповідач",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматична відповідь на вхідні повідомлення. Якщо хтось надсилає вам кілька повідомлень, ця автоматична відповідь надсилатиметься щонайбільше раз на 4 дні.",
     "Please connect to a sieve server first." : "Спочатку з'єднайтеся із сервером sieve.",
-    "Sieve filter rules" : "Правила фільтру Sieve",
+    "Filters" : "Фільтри",
     "Mail server" : "Поштовий сервер",
-    "Sieve filter server" : "Сервер Sieve для фільтрування",
     "Mailbox search" : "Пошук поштової скриньки",
     "Update alias" : "Оновити синонім",
     "Rename alias" : "Перейменувати синонім",
@@ -490,6 +489,11 @@ OC.L10N.register(
     "Train" : "Потяг",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} від {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Потяг з {depStation} до {arrStation}",
+    "Delete filter" : "Вилучити фільтр",
+    "Operator" : "Оператор",
+    "Actions" : "Дії",
+    "New action" : "Нова дія",
+    "Priority" : "Пріоритет",
     "Mail app" : "Електронна пошта",
     "The mail app allows users to read mails on their IMAP accounts." : "Застосунок пошти дозволяє користувачам переглядати з їхніх облікових записів IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Тут ви можете знайти налаштування для всього примірника хмари. Налаштування користувача розташовані у застосунку (див. у лівому нижньому куті).",
@@ -552,6 +556,8 @@ OC.L10N.register(
     "Redirect" : "Перенаправлення",
     "The link leads to %s" : "Посилання веде до %s",
     "Continue to %s" : "Перейти до %s",
+    "Sieve filter rules" : "Правила фільтру Sieve",
+    "Sieve filter server" : "Сервер Sieve для фільтрування",
     "Account creation" : "Створення облікового запису"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
