@@ -56,6 +56,7 @@ use OCA\Mail\Notification\Notifier;
 use OCA\Mail\Search\FilteringProvider;
 use OCA\Mail\Search\Provider;
 use OCA\Mail\Service\Attachment\AttachmentService;
+use OCA\Mail\Service\Avatar\FaviconDataAccess;
 use OCA\Mail\Service\AvatarService;
 use OCA\Mail\Service\DkimService;
 use OCA\Mail\Service\DkimValidator;
@@ -64,6 +65,7 @@ use OCA\Mail\Service\MailTransmission;
 use OCA\Mail\Service\Search\MailSearch;
 use OCA\Mail\Service\TrustedSenderService;
 use OCA\Mail\Service\UserPreferenceService;
+use OCA\Mail\Vendor\Favicon\Favicon;
 use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
@@ -99,6 +101,13 @@ class Application extends App implements IBootstrap {
 
 			return $userContainer->getUserFolder($uid);
 		});
+		$context->registerService(Favicon::class, function (ContainerInterface $c) {
+			$favicon = new Favicon();
+			$favicon->setDataAccess(
+				$c->get(FaviconDataAccess::class),
+			);
+			return $favicon;
+		});
 
 		$context->registerServiceAlias(IAvatarService::class, AvatarService::class);
 		$context->registerServiceAlias(IAttachmentService::class, AttachmentService::class);
