@@ -3,27 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2021 Anna Larch <anna@nextcloud.com>
- *
- * @author 2021 Anna Larch <anna@nextcloud.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * @link https://github.com/nextcloud/mail/issues/25
- * @link https://github.com/nextcloud/mail/issues/4780
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Migration;
@@ -65,7 +46,7 @@ class MigrateImportantFromImapAndDb {
 		try {
 			$uids = $this->messageMapper->getFlagged($client, $mailbox, '$important');
 		} catch (Horde_Imap_Client_Exception $e) {
-			throw new ServiceException("Could not fetch UIDs of important messages: " . $e->getMessage(), 0, $e);
+			throw new ServiceException('Could not fetch UIDs of important messages: ' . $e->getMessage(), 0, $e);
 		}
 		// add $label1 for all that are tagged on IMAP
 		if ($uids !== []) {
