@@ -3,28 +3,15 @@
 declare(strict_types=1);
 
 /**
- * @author Hamza Mahjoubi <hamzamahjoubi22@proton.me>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2023-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\Service\AiIntegrations;
 
 use JsonException;
 use OCA\Mail\Account;
+use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\Message;
@@ -32,6 +19,7 @@ use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\IMAP\IMAPClientFactory;
 use OCA\Mail\Model\EventData;
 use OCA\Mail\Model\IMAPMessage;
+use OCP\IConfig;
 use OCP\TextProcessing\FreePromptTaskType;
 use OCP\TextProcessing\IManager;
 use OCP\TextProcessing\SummaryTaskType;
@@ -54,9 +42,11 @@ class AiIntegrationsService {
 	/** @var IMAPClientFactory */
 	private IMAPClientFactory $clientFactory;
 
-	/** @var IMailManager  */
+	/** @var IMailManager */
 	private IMailManager $mailManager;
 
+	private IConfig $config;
+
 	private const EVENT_DATA_PROMPT_PREAMBLE = <<<PROMPT
 I am scheduling an event based on an email thread and need an event title and agenda. Provide the result as JSON with keys for "title" and "agenda". For example ```{ "title": "Project kick-off meeting", "agenda": "* Introduction\\n* Project goals\\n* Next steps" }```.
 
@@ -64,11 +54,12 @@ The email contents are:
 
 PROMPT;
 
-	public function __construct(ContainerInterface $container, Cache $cache, IMAPClientFactory $clientFactory, IMailManager $mailManager) {
+	public function __construct(ContainerInterface $container, Cache $cache, IMAPClientFactory $clientFactory, IMailManager $mailManager, IConfig $config) {
 		$this->container = $container;
 		$this->cache = $cache;
 		$this->clientFactory = $clientFactory;
 		$this->mailManager = $mailManager;
+		$this->config = $config;
 	}
 	/**
 	 * @param Account $account
@@ -76,7 +67,7 @@ PROMPT;
 	 * @param array $messages
 	 * @param string $currentUserId
 	 *
-	 * @return  null|string
+	 * @return null|string
 	 *
 	 * @throws ServiceException
 	 */
@@ -112,7 +103,7 @@ PROMPT;
 			}
 
 			$taskPrompt = implode("\n", $messagesBodies);
-			$summaryTask = new Task(SummaryTaskType::class, $taskPrompt, "mail", $currentUserId, $threadId);
+			$summaryTask = new Task(SummaryTaskType::class, $taskPrompt, 'mail', $currentUserId, $threadId);
 			$manager->runTask($summaryTask);
 			$summary = $summaryTask->getOutput();
 
@@ -156,7 +147,7 @@ PROMPT;
 		$task = new Task(
 			FreePromptTaskType::class,
 			self::EVENT_DATA_PROMPT_PREAMBLE . implode("\n\n---\n\n", $messageBodies),
-			"mail",
+			'mail',
 			$currentUserId,
 			"event_data_$threadId",
 		);
@@ -170,9 +161,10 @@ PROMPT;
 	}
 
 	/**
-	 * @return string[]
+	 * @return ?string[]
+	 * @throws ServiceException
 	 */
-	public function getSmartReply(Account $account, Mailbox $mailbox, Message $message, string $currentUserId): array {
+	public function getSmartReply(Account $account, Mailbox $mailbox, Message $message, string $currentUserId): ?array {
 		try {
 			$manager = $this->container->get(IManager::class);
 		} catch (\Throwable $e) {
@@ -181,7 +173,7 @@ PROMPT;
 		if (in_array(FreePromptTaskType::class, $manager->getAvailableTaskTypes(), true)) {
 			$cachedReplies = $this->cache->getValue('smartReplies_'.$message->getId());
 			if ($cachedReplies) {
-				return explode("|", $cachedReplies);
+				return json_decode($cachedReplies, true, 512);
 			}
 			$client = $this->clientFactory->getClient($account);
 			try {
@@ -199,17 +191,101 @@ PROMPT;
 			} finally {
 				$client->logout();
 			}
-			$prompt = "Suggest 2 replies to the following email. Each reply should be 25 characters max. Separate the replies with  \"| \", like for example  \"Yes! | No, I'm not available \". Do not print anything else. The email contents are : ".$messageBody."";
+			$prompt = "You are tasked with formulating helpful replies or reply templates to e-mails provided that have been sent to me. If you don't know some relevant information for answering the e-mails (like my schedule) leave blanks in the text that can later be filled by me. You must write the replies from my point of view as replies to the original sender of the provided e-mail!
+
+			Formulate two extremely succinct reply suggestions to the provided ***E-MAIL***. Please, do not invent any context for the replies but, rather, leave blanks for me to fill in with relevant information where necessary. Provide the output formatted as valid JSON with the keys 'reply1' and 'reply2' for the reply suggestions.
+
+			Each suggestion must be of 25 characters or less.
+
+			Here is the ***E-MAIL*** for which you must suggest the replies to:
+
+			***START_OF_E-MAIL***".$messageBody."
+
+			***END_OF_E-MAIL***
+
+			Please, output *ONLY* a valid JSON string with the keys 'reply1' and 'reply2' for the reply suggestions. Leave out any other text besides the JSON! Be extremely succinct and write the replies from my point of view.
+			 ";
 			$task = new Task(FreePromptTaskType::class, $prompt, 'mail,', $currentUserId);
 			$manager->runTask($task);
-			$replies = array_slice(explode("|", $task->getOutput()), 0, 2);
-			$this->cache->addValue('smartReplies_'.$message->getUid(), implode("|", $replies));
-			return $replies;
-			
+			$replies = $task->getOutput();
+			try {
+				$decoded = json_decode($replies, true, 512, JSON_THROW_ON_ERROR);
+				$this->cache->addValue('smartReplies_'.$message->getId(), $replies);
+				return $decoded;
+			} catch (JsonException $e) {
+				throw new ServiceException('Failed to decode smart replies JSON output', $e);
+			}
 		} else {
 			throw new ServiceException('No language model available for smart replies');
 		}
+	}
 
+	/**
+	 * Analyze whether a sender of an email expects a reply based on the email's body.
+	 *
+	 * @throws ServiceException
+	 */
+	public function requiresFollowUp(
+		Account $account,
+		Mailbox $mailbox,
+		Message $message,
+		string $currentUserId,
+	): bool {
+		try {
+			$manager = $this->container->get(IManager::class);
+		} catch (ContainerExceptionInterface $e) {
+			throw new ServiceException(
+				'Text processing is not available in your current Nextcloud version',
+				0,
+				$e,
+			);
+		}
+
+		if (!in_array(FreePromptTaskType::class, $manager->getAvailableTaskTypes(), true)) {
+			throw new ServiceException('No language model available for smart replies');
+		}
+
+		$client = $this->clientFactory->getClient($account);
+		try {
+			$imapMessage = $this->mailManager->getImapMessage(
+				$client,
+				$account,
+				$mailbox,
+				$message->getUid(),
+				true,
+			);
+		} finally {
+			$client->logout();
+		}
+
+		if (!$this->isPersonalEmail($imapMessage)) {
+			return false;
+		}
+
+		$messageBody = $imapMessage->getPlainBody();
+		$messageBody = str_replace('"', '\"', $messageBody);
+
+		$prompt = "Consider the following TypeScript function prototype:
+---
+/**
+ * This function takes in an email text and returns a boolean indicating whether the email author expects a response.
+ *
+ * @param emailText - string with the email text
+ * @returns boolean true if the email expects a reply, false if not
+ */
+declare function doesEmailExpectReply(emailText: string): Promise<boolean>;
+---
+Tell me what the function outputs for the following parameters.
+
+emailText: \"$messageBody\"
+The JSON output should be in the form: {\"expectsReply\": true}
+Never return null or undefined.";
+		$task = new Task(FreePromptTaskType::class, $prompt, Application::APP_ID, $currentUserId);
+
+		$manager->runTask($task);
+
+		// Can't use json_decode() here because the output contains additional garbage
+		return preg_match('/{\s*"expectsReply"\s*:\s*true\s*}/i', $task->getOutput()) === 1;
 	}
 
 	public function isLlmAvailable(string $taskType): bool {
@@ -221,6 +297,13 @@ PROMPT;
 		return in_array($taskType, $manager->getAvailableTaskTypes(), true);
 	}
 
+	/**
+	 * Whether the llm_processing admin setting is enabled globally on this instance.
+	 */
+	public function isLlmProcessingEnabled(): bool {
+		return $this->config->getAppValue(Application::APP_ID, 'llm_processing', 'no') === 'yes';
+	}
+
 	private function isPersonalEmail(IMAPMessage $imapMessage): bool {
 
 		if ($imapMessage->isOneClickUnsubscribe() || $imapMessage->getUnsubscribeUrl() !== null) {
@@ -234,7 +317,7 @@ PROMPT;
 		];
 
 		$senderAddress = $imapMessage->getFrom()->first()?->getEmail();
-		
+
 		if($senderAddress !== null) {
 			foreach ($commonPatterns as $pattern) {
 				if (stripos($senderAddress, $pattern) !== false) {
