@@ -3,23 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Richard Steinmetz <richard@steinmetz.cloud>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\Service;
@@ -45,6 +30,7 @@ use OCA\Mail\Events\MessageDeletedEvent;
 use OCA\Mail\Events\MessageFlaggedEvent;
 use OCA\Mail\Exception\ClientException;
 use OCA\Mail\Exception\ServiceException;
+use OCA\Mail\Exception\SmimeDecryptException;
 use OCA\Mail\Exception\TrashMailboxNotSetException;
 use OCA\Mail\Folder;
 use OCA\Mail\IMAP\FolderMapper;
@@ -164,7 +150,7 @@ class MailManager implements IMailManager {
 			$this->folderMapper->fetchFolderAcls([$folder], $client);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
-				"Could not get mailbox status: " . $e->getMessage(),
+				'Could not get mailbox status: ' . $e->getMessage(),
 				$e->getCode(),
 				$e
 			);
@@ -188,6 +174,7 @@ class MailManager implements IMailManager {
 	 * @return IMAPMessage
 	 *
 	 * @throws ServiceException
+	 * @throws SmimeDecryptException
 	 */
 	public function getImapMessage(Horde_Imap_Client_Socket $client,
 		Account $account,
@@ -202,9 +189,9 @@ class MailManager implements IMailManager {
 				$account->getUserId(),
 				$loadBody
 			);
-		} catch (Horde_Imap_Client_Exception | DoesNotExistException $e) {
+		} catch (Horde_Imap_Client_Exception|DoesNotExistException $e) {
 			throw new ServiceException(
-				"Could not load message",
+				'Could not load message',
 				$e->getCode(),
 				$e
 			);
@@ -275,8 +262,8 @@ class MailManager implements IMailManager {
 				$account->getUserId(),
 				false,
 			);
-		} catch (Horde_Imap_Client_Exception | DoesNotExistException $e) {
-			throw new ServiceException("Could not load message", 0, $e);
+		} catch (Horde_Imap_Client_Exception|DoesNotExistException $e) {
+			throw new ServiceException('Could not load message', 0, $e);
 		}
 	}
 
@@ -367,7 +354,7 @@ class MailManager implements IMailManager {
 			}
 			$trashMailbox = $this->mailboxMapper->findById($trashMailboxId);
 		} catch (DoesNotExistException $e) {
-			throw new ServiceException("No trash folder", 0, $e);
+			throw new ServiceException('No trash folder', 0, $e);
 		}
 
 		if ($mailbox->getName() === $trashMailbox->getName()) {
@@ -431,7 +418,7 @@ class MailManager implements IMailManager {
 			$client->subscribeMailbox($mailbox->getName(), $subscribed);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
-				"Could not set subscription status for mailbox " . $mailbox->getId() . " on IMAP: " . $e->getMessage(),
+				'Could not set subscription status for mailbox ' . $mailbox->getId() . ' on IMAP: ' . $e->getMessage(),
 				$e->getCode(),
 				$e
 			);
@@ -480,7 +467,7 @@ class MailManager implements IMailManager {
 			}
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
-				"Could not set message flag on IMAP: " . $e->getMessage(),
+				'Could not set message flag on IMAP: ' . $e->getMessage(),
 				$e->getCode(),
 				$e
 			);
@@ -522,7 +509,7 @@ class MailManager implements IMailManager {
 				}
 			} catch (Horde_Imap_Client_Exception $e) {
 				throw new ServiceException(
-					"Could not set message keyword on IMAP: " . $e->getMessage(),
+					'Could not set message keyword on IMAP: ' . $e->getMessage(),
 					$e->getCode(),
 					$e
 				);
@@ -799,7 +786,7 @@ class MailManager implements IMailManager {
 			$capabilities = $client->status($mailbox, Horde_Imap_Client::STATUS_PERMFLAGS);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
-				"Could not get message flag options from IMAP: " . $e->getMessage(),
+				'Could not get message flag options from IMAP: ' . $e->getMessage(),
 				$e->getCode(),
 				$e
 			);
