@@ -3,25 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright Copyright (c) 2023 Richard Steinmetz <richard@steinmetz.cloud>
- *
- * @author Richard Steinmetz <richard@steinmetz.cloud>
- *
- * @license AGPL-3.0-or-later
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Service\OutOfOffice;
@@ -90,12 +73,12 @@ class OutOfOfficeParser {
 			$state = $nextState;
 		}
 
-		return new OutOfOfficeParserResult($data, $sieveScript, implode("\n", $scriptOut));
+		return new OutOfOfficeParserResult($data, $sieveScript, implode("\r\n", $scriptOut));
 	}
 
 	/**
 	 * @param string[] $allowedRecipients Respond to envelopes that are addressed to the given addresses.
-	 *								      Should be the main address and aliases of the account.
+	 *                                    Should be the main address and aliases of the account.
 	 *                                    An empty array will leave the decision to the sieve implementation.
 	 *
 	 * @throws OutOfOfficeParserException If the given out-of-office state is missing required fields.
@@ -116,7 +99,7 @@ class OutOfOfficeParser {
 
 		if (!$state->isEnabled()) {
 			//unset($jsonData['start'], $jsonString['end']);
-			return implode("\n", [
+			return implode("\r\n", [
 				$untouchedScript,
 				self::SEPARATOR,
 				self::DATA_MARKER . $stateJsonString,
@@ -190,7 +173,7 @@ class OutOfOfficeParser {
 			self::SEPARATOR,
 		]);
 
-		return implode("\n", array_merge(
+		return implode("\r\n", array_merge(
 			$requireSection,
 			[$untouchedScript],
 			$vacationSection,
